@@ -9,28 +9,28 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.1.") or
-    raise "ruby lib version (3.1.7) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.2.") or
+    raise "ruby lib version (3.2.9) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.1/3.1.0/x86_64-darwin13")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.2/3.2.0/x86_64-darwin13")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "1"
-  CONFIG["TEENY"] = "7"
-  CONFIG["PATCHLEVEL"] = "261"
+  CONFIG["MINOR"] = "2"
+  CONFIG["TEENY"] = "9"
+  CONFIG["PATCHLEVEL"] = "265"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.1"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.1"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.2"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.2"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_API_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.1.pc"
+  CONFIG["ruby_pc"] = "ruby-3.2.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -41,11 +41,11 @@ module RbConfig
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
   CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
-  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.1.7"
+  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.2.9"
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=3.1' '--with-rubyhdrdir=/opt/local/include/ruby-3.1.7' '--with-rubylibprefix=/opt/local/lib/ruby3.1' '--with-openssl-dir=/opt/local/libexec/openssl11' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/opt/local/bin/clang-mp-16' 'CXX=/opt/local/bin/clang++-mp-16' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -arch x86_64' 'CPPFLAGS=-isystem/opt/local/include/LegacySupport -I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch x86_64'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=3.2' '--with-rubyhdrdir=/opt/local/include/ruby-3.2.9' '--with-rubylibprefix=/opt/local/lib/ruby3.2' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CXX=/usr/bin/clang++' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -arch x86_64' 'CPPFLAGS=-isystem/opt/local/include/LegacySupport -I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.1.0"
+  CONFIG["ruby_version"] = "3.2.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin13"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -72,13 +72,14 @@ module RbConfig
   CONFIG["rubyarchprefix"] = "$(rubylibprefix)/$(arch)"
   CONFIG["MAKEFILES"] = "Makefile GNUmakefile"
   CONFIG["PLATFORM_DIR"] = ""
+  CONFIG["COROUTINE_TYPE"] = "amd64"
   CONFIG["THREAD_MODEL"] = "pthread"
   CONFIG["SYMBOL_PREFIX"] = "_"
   CONFIG["EXPORT_PREFIX"] = ""
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["COMMON_MACROS"] = ""
   CONFIG["COMMON_LIBS"] = ""
-  CONFIG["MAINLIBS"] = "-lpthread -ldl -lobjc"
+  CONFIG["MAINLIBS"] = "-ldl -lobjc -lpthread "
   CONFIG["ENABLE_SHARED"] = "yes"
   CONFIG["DLDSHARED"] = "$(CC) -dynamiclib"
   CONFIG["DLDLIBS"] = ""
@@ -95,14 +96,20 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["EXTLDFLAGS"] = ""
-  CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wold-style-definition -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens -Wundef"
+  CONFIG["strict_warnflags"] = ""
+  CONFIG["warnflags"] = "-Wall -Wextra -Wextra-tokens -Wdeprecated-declarations -Wdivision-by-zero -Wdiv-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wold-style-definition -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["NULLCMD"] = ":"
   CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "yes"
+  CONFIG["YJIT_OBJ"] = ""
+  CONFIG["YJIT_LIBS"] = ""
+  CONFIG["CARGO_BUILD_ARGS"] = ""
+  CONFIG["YJIT_SUPPORT"] = "no"
+  CONFIG["CARGO"] = ""
+  CONFIG["RUSTC"] = "no"
   CONFIG["MJIT_SUPPORT"] = "yes"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
@@ -111,18 +118,18 @@ module RbConfig
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.1"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.2"
   CONFIG["setup"] = "Setup"
-  CONFIG["ENCSTATIC"] = ""
-  CONFIG["EXTSTATIC"] = ""
   CONFIG["SOEXT"] = "dylib"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "DYLD_INSERT_LIBRARIES"
-  CONFIG["LIBPATHENV"] = "DYLD_FALLBACK_LIBRARY_PATH"
+  CONFIG["LIBPATHENV"] = "DYLD_LIBRARY_PATH"
   CONFIG["RPATHFLAG"] = ""
   CONFIG["LIBPATHFLAG"] = " -L%s"
   CONFIG["LINK_SO"] = "\n$(POSTLINK)"
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
+  CONFIG["ENCSTATIC"] = ""
+  CONFIG["EXTSTATIC"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
   CONFIG["DLEXT"] = "bundle"
@@ -131,16 +138,17 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = "-fno-common"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = " -arch x86_64"
-  CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl11/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -arch x86_64 -L/opt/local/lib -Wl,-multiply_defined,suppress -Wl,-undefined,dynamic_lookup"
+  CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl3/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -arch x86_64 -L/opt/local/lib -Wl,-multiply_defined,suppress -Wl,-undefined,dynamic_lookup"
   CONFIG["ALLOCA"] = ""
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
-  CONFIG["dsymutil"] = "/opt/local/bin/dsymutil-mp-16"
+  CONFIG["dsymutil"] = "dsymutil"
   CONFIG["codesign"] = "codesign"
   CONFIG["cleanlibs"] = "$(TARGET_SO).dSYM"
-  CONFIG["POSTLINK"] = "/opt/local/bin/dsymutil-mp-16 $@; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
+  CONFIG["POSTLINK"] = "dsymutil $@; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
   CONFIG["incflags"] = "-I/opt/local/include"
   CONFIG["WERRORFLAG"] = "-Werror"
+  CONFIG["RUBY_DEVEL"] = ""
   CONFIG["CHDIR"] = "cd -P"
   CONFIG["RMALL"] = "rm -fr"
   CONFIG["RMDIRS"] = "rmdir -p"
@@ -150,7 +158,6 @@ module RbConfig
   CONFIG["PKG_CONFIG"] = "pkg-config"
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
-  CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
   CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
   CONFIG["INSTALL_SCRIPT"] = "$(INSTALL)"
@@ -162,9 +169,9 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcu "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "clang version 16.0.6\nTarget: x86_64-apple-darwin13.4.0\nThread model: posix\nInstalledDir: /opt/local/libexec/llvm-16/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "Apple LLVM version 6.0 (clang-600.0.57) (based on LLVM 3.5svn)\nTarget: x86_64-apple-darwin13.4.0\nThread model: posix"
   CONFIG["CC_VERSION"] = "$(CC) --version"
-  CONFIG["MJIT_CC"] = "/opt/local/bin/clang-mp-16"
+  CONFIG["MJIT_CC"] = "/usr/bin/clang -std=gnu11 -std=gnu11"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
@@ -172,29 +179,31 @@ module RbConfig
   CONFIG["GNU_LD"] = "no"
   CONFIG["GCC"] = "yes"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -fdeclspec"
+  CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-isystem/opt/local/include/LegacySupport -I/opt/local/libexec/openssl11/include -isystem/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl11/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -fstack-protector-strong -L/opt/local/lib -L/opt/local/libexec/llvm-16/lib/clang/16/lib"
-  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os $(cflags) -fno-common"
+  CONFIG["CPPFLAGS"] = "-isystem/opt/local/include/LegacySupport -I/opt/local/libexec/openssl3/include -isystem/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl3/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -fstack-protector -L/opt/local/lib"
+  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl3/include -Os -fno-common"
   CONFIG["STRIP"] = "strip -A -n"
   CONFIG["RANLIB"] = "/opt/local/bin/ranlib"
   CONFIG["OBJDUMP"] = ""
   CONFIG["OBJCOPY"] = ":"
-  CONFIG["NM"] = "/opt/local/bin/nm"
-  CONFIG["LD"] = "/opt/local/bin/clang-mp-16"
-  CONFIG["CXX"] = "/opt/local/bin/clang++-mp-16"
+  CONFIG["NM"] = "nm"
+  CONFIG["LD"] = "ld"
+  CONFIG["CXX"] = "/usr/bin/clang++ -std=gnu++11"
   CONFIG["AS"] = "as"
   CONFIG["AR"] = "/opt/local/bin/ar"
-  CONFIG["CC"] = "/opt/local/bin/clang-mp-16"
+  CONFIG["CC"] = "/usr/bin/clang -std=gnu11"
+  CONFIG["wasmoptflags"] = ""
+  CONFIG["WASMOPT"] = ""
   CONFIG["target_os"] = "darwin13"
   CONFIG["target_vendor"] = "apple"
   CONFIG["target_cpu"] = "x86_64"
-  CONFIG["target"] = "x86_64-apple-darwin13"
-  CONFIG["host_os"] = "darwin13"
-  CONFIG["host_vendor"] = "apple"
-  CONFIG["host_cpu"] = "x86_64"
-  CONFIG["host"] = "x86_64-apple-darwin13"
+  CONFIG["target"] = "$(target_cpu)-$(target_vendor)-$(target_os)"
+  CONFIG["host_os"] = "$(target_os)"
+  CONFIG["host_vendor"] = "$(target_vendor)"
+  CONFIG["host_cpu"] = "$(target_cpu)"
+  CONFIG["host"] = "$(target)"
   CONFIG["build_os"] = "darwin13.4.0"
   CONFIG["build_vendor"] = "apple"
   CONFIG["build_cpu"] = "x86_64"
@@ -208,11 +217,12 @@ module RbConfig
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
-  CONFIG["cflags"] = "-fdeclspec $(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["target_alias"] = ""
-  CONFIG["host_alias"] = ""
+  CONFIG["host_alias"] = "$(target_alias)"
   CONFIG["build_alias"] = ""
-  CONFIG["LIBS"] = ""
+  CONFIG["LIBS"] = "-lpthread "
   CONFIG["ECHO_T"] = ""
   CONFIG["ECHO_N"] = ""
   CONFIG["ECHO_C"] = "\\\\c"
@@ -237,7 +247,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&3.1&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&3.2&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -247,8 +257,8 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["UNICODE_VERSION"] = "13.0.0"
-  CONFIG["UNICODE_EMOJI_VERSION"] = "13.1"
+  CONFIG["UNICODE_VERSION"] = "15.0.0"
+  CONFIG["UNICODE_EMOJI_VERSION"] = "15.0"
   CONFIG["SDKROOT"] = ""
   CONFIG["platform"] = "$(arch)"
   CONFIG["archdir"] = "$(rubyarchdir)"
@@ -310,7 +320,6 @@ module RbConfig
     RbConfig::expand(val)
   end
 
-  # :nodoc:
   # call-seq:
   #
   #   RbConfig.fire_update!(key, val)               -> array
@@ -326,7 +335,7 @@ module RbConfig
   #   RbConfig::CONFIG.values_at("CC", "LDSHARED")          # => ["gcc-8", "gcc-8 -shared"]
   #
   # returns updated keys list, or +nil+ if nothing changed.
-  def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG)
+  def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG) # :nodoc:
     return if mkconf[key] == val
     mkconf[key] = val
     keys = [key]
